@@ -3,8 +3,8 @@ use strict;
 use warnings;
 
 package Pod::Wordlist::hanekomu;
-BEGIN {
-  $Pod::Wordlist::hanekomu::VERSION = '1.102640';
+{
+  $Pod::Wordlist::hanekomu::VERSION = '1.113620';
 }
 # ABSTRACT: Add words for spell checking POD
 use Test::Spelling;
@@ -14,7 +14,10 @@ our @person_names = qw(
   Achim
   Adam
   Conway
+  Cushing
   Damian
+  Doherty
+  Doran
   Eilam
   Ekker
   Florian
@@ -22,6 +25,7 @@ our @person_names = qw(
   Heinz
   Helmberger
   Hofstetter
+  Lapworth
   Marcel
   Mark
   Metheringham
@@ -74,6 +78,7 @@ our @tech_names = qw(
   svk
   TIMTOWTDI
   Unicode
+  UTF
   URI
   URIs
   W3CDTF
@@ -86,12 +91,16 @@ our @stopwords = qw(
   adaptees
   administrativa
   afterwards
+  aggregator
+  aggregators
   array's
   backend
   behaviour
   benchmarked
   blog
   blogs
+  breakpoint
+  breakpoints
   bugtracker
   bundle's
   callback
@@ -102,6 +111,7 @@ our @stopwords = qw(
   configurator
   configurators
   crosscutting
+  debugger's
   denormalized
   distname
   dotfile
@@ -147,12 +157,16 @@ our @stopwords = qw(
   pointcuts
   prepends
   preprocessed
+  probe's
   redispatch
   reusability
   ref
+  runtime
   san
+  seekable
   segment's
   shipit
+  sigils
   startup
   storable
   storages
@@ -200,7 +214,7 @@ Pod::Wordlist::hanekomu - Add words for spell checking POD
 
 =head1 VERSION
 
-version 1.102640
+version 1.113620
 
 =head1 SYNOPSIS
 
@@ -222,7 +236,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Wordlist-hanekomu>.
 
 =head1 AVAILABILITY
 
@@ -231,7 +245,7 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<http://search.cpan.org/dist/Pod-Wordlist-hanekomu/>.
 
 The development version lives at L<http://github.com/hanekomu/Pod-Wordlist-hanekomu>
-and may be cloned from L<git://github.com/hanekomu/Pod-Wordlist-hanekomu>.
+and may be cloned from L<git://github.com/hanekomu/Pod-Wordlist-hanekomu.git>.
 Instead of sending patches, please fork this project using the standard
 git and github infrastructure.
 
